rum

package
v1.253.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 30, 2026 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func WithContentTypeApplicationJSON

func WithContentTypeApplicationJSON(r *runtime.ClientOperation)

WithContentTypeApplicationJSON sets the Content-Type header to "application/json".

func WithContentTypeMultipartFormData

func WithContentTypeMultipartFormData(r *runtime.ClientOperation)

WithContentTypeMultipartFormData sets the Content-Type header to "multipart/form-data".

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client for rum API

func (*Client) SetTransport

func (a *Client) SetTransport(transport runtime.ClientTransport)

SetTransport changes the transport on the client

func (*Client) UploadSourceMap

func (a *Client) UploadSourceMap(params *UploadSourceMapParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*UploadSourceMapCreated, error)

UploadSourceMap uploads a sourcemap

Accepts multipart/form-data with app_id, release_id, and file fields.

type ClientOption

type ClientOption func(*runtime.ClientOperation)

ClientOption may be used to customize the behavior of Client methods.

func WithContentType

func WithContentType(mime string) ClientOption

WithContentType allows the client to force the Content-Type header to negotiate a specific Consumer from the server.

You may use this option to set arbitrary extensions to your MIME media type.

type ClientService

type ClientService interface {
	UploadSourceMap(params *UploadSourceMapParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*UploadSourceMapCreated, error)

	SetTransport(transport runtime.ClientTransport)
}

ClientService is the interface for Client methods

func New

func New(transport runtime.ClientTransport, formats strfmt.Registry) ClientService

New creates a new rum API client.

func NewClientWithBasicAuth

func NewClientWithBasicAuth(host, basePath, scheme, user, password string) ClientService

New creates a new rum API client with basic auth credentials. It takes the following parameters: - host: http host (github.com). - basePath: any base path for the API client ("/v1", "/v3"). - scheme: http scheme ("http", "https"). - user: user for basic authentication header. - password: password for basic authentication header.

func NewClientWithBearerToken

func NewClientWithBearerToken(host, basePath, scheme, bearerToken string) ClientService

New creates a new rum API client with a bearer token for authentication. It takes the following parameters: - host: http host (github.com). - basePath: any base path for the API client ("/v1", "/v3"). - scheme: http scheme ("http", "https"). - bearerToken: bearer token for Bearer authentication header.

type UploadSourceMapBadGateway

type UploadSourceMapBadGateway struct {
	Payload *models.ErrorResponse
}

UploadSourceMapBadGateway describes a response with status code 502, with default header values.

UploadSourceMapBadGateway upload source map bad gateway

func NewUploadSourceMapBadGateway

func NewUploadSourceMapBadGateway() *UploadSourceMapBadGateway

NewUploadSourceMapBadGateway creates a UploadSourceMapBadGateway with default headers values

func (*UploadSourceMapBadGateway) Code

func (o *UploadSourceMapBadGateway) Code() int

Code gets the status code for the upload source map bad gateway response

func (*UploadSourceMapBadGateway) Error

func (o *UploadSourceMapBadGateway) Error() string

func (*UploadSourceMapBadGateway) GetPayload

func (*UploadSourceMapBadGateway) IsClientError

func (o *UploadSourceMapBadGateway) IsClientError() bool

IsClientError returns true when this upload source map bad gateway response has a 4xx status code

func (*UploadSourceMapBadGateway) IsCode

func (o *UploadSourceMapBadGateway) IsCode(code int) bool

IsCode returns true when this upload source map bad gateway response a status code equal to that given

func (*UploadSourceMapBadGateway) IsRedirect

func (o *UploadSourceMapBadGateway) IsRedirect() bool

IsRedirect returns true when this upload source map bad gateway response has a 3xx status code

func (*UploadSourceMapBadGateway) IsServerError

func (o *UploadSourceMapBadGateway) IsServerError() bool

IsServerError returns true when this upload source map bad gateway response has a 5xx status code

func (*UploadSourceMapBadGateway) IsSuccess

func (o *UploadSourceMapBadGateway) IsSuccess() bool

IsSuccess returns true when this upload source map bad gateway response has a 2xx status code

func (*UploadSourceMapBadGateway) String

func (o *UploadSourceMapBadGateway) String() string

type UploadSourceMapBadRequest

type UploadSourceMapBadRequest struct {
	Payload *models.ErrorResponse
}

UploadSourceMapBadRequest describes a response with status code 400, with default header values.

UploadSourceMapBadRequest upload source map bad request

func NewUploadSourceMapBadRequest

func NewUploadSourceMapBadRequest() *UploadSourceMapBadRequest

NewUploadSourceMapBadRequest creates a UploadSourceMapBadRequest with default headers values

func (*UploadSourceMapBadRequest) Code

func (o *UploadSourceMapBadRequest) Code() int

Code gets the status code for the upload source map bad request response

func (*UploadSourceMapBadRequest) Error

func (o *UploadSourceMapBadRequest) Error() string

func (*UploadSourceMapBadRequest) GetPayload

func (*UploadSourceMapBadRequest) IsClientError

func (o *UploadSourceMapBadRequest) IsClientError() bool

IsClientError returns true when this upload source map bad request response has a 4xx status code

func (*UploadSourceMapBadRequest) IsCode

func (o *UploadSourceMapBadRequest) IsCode(code int) bool

IsCode returns true when this upload source map bad request response a status code equal to that given

func (*UploadSourceMapBadRequest) IsRedirect

func (o *UploadSourceMapBadRequest) IsRedirect() bool

IsRedirect returns true when this upload source map bad request response has a 3xx status code

func (*UploadSourceMapBadRequest) IsServerError

func (o *UploadSourceMapBadRequest) IsServerError() bool

IsServerError returns true when this upload source map bad request response has a 5xx status code

func (*UploadSourceMapBadRequest) IsSuccess

func (o *UploadSourceMapBadRequest) IsSuccess() bool

IsSuccess returns true when this upload source map bad request response has a 2xx status code

func (*UploadSourceMapBadRequest) String

func (o *UploadSourceMapBadRequest) String() string

type UploadSourceMapCreated

type UploadSourceMapCreated struct {
	Payload *models.SourceMapUploadResponse
}

UploadSourceMapCreated describes a response with status code 201, with default header values.

UploadSourceMapCreated upload source map created

func NewUploadSourceMapCreated

func NewUploadSourceMapCreated() *UploadSourceMapCreated

NewUploadSourceMapCreated creates a UploadSourceMapCreated with default headers values

func (*UploadSourceMapCreated) Code

func (o *UploadSourceMapCreated) Code() int

Code gets the status code for the upload source map created response

func (*UploadSourceMapCreated) Error

func (o *UploadSourceMapCreated) Error() string

func (*UploadSourceMapCreated) GetPayload

func (*UploadSourceMapCreated) IsClientError

func (o *UploadSourceMapCreated) IsClientError() bool

IsClientError returns true when this upload source map created response has a 4xx status code

func (*UploadSourceMapCreated) IsCode

func (o *UploadSourceMapCreated) IsCode(code int) bool

IsCode returns true when this upload source map created response a status code equal to that given

func (*UploadSourceMapCreated) IsRedirect

func (o *UploadSourceMapCreated) IsRedirect() bool

IsRedirect returns true when this upload source map created response has a 3xx status code

func (*UploadSourceMapCreated) IsServerError

func (o *UploadSourceMapCreated) IsServerError() bool

IsServerError returns true when this upload source map created response has a 5xx status code

func (*UploadSourceMapCreated) IsSuccess

func (o *UploadSourceMapCreated) IsSuccess() bool

IsSuccess returns true when this upload source map created response has a 2xx status code

func (*UploadSourceMapCreated) String

func (o *UploadSourceMapCreated) String() string

type UploadSourceMapInternalServerError

type UploadSourceMapInternalServerError struct {
	Payload *models.ErrorResponse
}

UploadSourceMapInternalServerError describes a response with status code 500, with default header values.

UploadSourceMapInternalServerError upload source map internal server error

func NewUploadSourceMapInternalServerError

func NewUploadSourceMapInternalServerError() *UploadSourceMapInternalServerError

NewUploadSourceMapInternalServerError creates a UploadSourceMapInternalServerError with default headers values

func (*UploadSourceMapInternalServerError) Code

Code gets the status code for the upload source map internal server error response

func (*UploadSourceMapInternalServerError) Error

func (*UploadSourceMapInternalServerError) GetPayload

func (*UploadSourceMapInternalServerError) IsClientError

func (o *UploadSourceMapInternalServerError) IsClientError() bool

IsClientError returns true when this upload source map internal server error response has a 4xx status code

func (*UploadSourceMapInternalServerError) IsCode

IsCode returns true when this upload source map internal server error response a status code equal to that given

func (*UploadSourceMapInternalServerError) IsRedirect

func (o *UploadSourceMapInternalServerError) IsRedirect() bool

IsRedirect returns true when this upload source map internal server error response has a 3xx status code

func (*UploadSourceMapInternalServerError) IsServerError

func (o *UploadSourceMapInternalServerError) IsServerError() bool

IsServerError returns true when this upload source map internal server error response has a 5xx status code

func (*UploadSourceMapInternalServerError) IsSuccess

IsSuccess returns true when this upload source map internal server error response has a 2xx status code

func (*UploadSourceMapInternalServerError) String

type UploadSourceMapParams

type UploadSourceMapParams struct {
	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

UploadSourceMapParams contains all the parameters to send to the API endpoint

for the upload source map operation.

Typically these are written to a http.Request.

func NewUploadSourceMapParams

func NewUploadSourceMapParams() *UploadSourceMapParams

NewUploadSourceMapParams creates a new UploadSourceMapParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewUploadSourceMapParamsWithContext

func NewUploadSourceMapParamsWithContext(ctx context.Context) *UploadSourceMapParams

NewUploadSourceMapParamsWithContext creates a new UploadSourceMapParams object with the ability to set a context for a request.

func NewUploadSourceMapParamsWithHTTPClient

func NewUploadSourceMapParamsWithHTTPClient(client *http.Client) *UploadSourceMapParams

NewUploadSourceMapParamsWithHTTPClient creates a new UploadSourceMapParams object with the ability to set a custom HTTPClient for a request.

func NewUploadSourceMapParamsWithTimeout

func NewUploadSourceMapParamsWithTimeout(timeout time.Duration) *UploadSourceMapParams

NewUploadSourceMapParamsWithTimeout creates a new UploadSourceMapParams object with the ability to set a timeout on a request.

func (*UploadSourceMapParams) SetContext

func (o *UploadSourceMapParams) SetContext(ctx context.Context)

SetContext adds the context to the upload source map params

func (*UploadSourceMapParams) SetDefaults

func (o *UploadSourceMapParams) SetDefaults()

SetDefaults hydrates default values in the upload source map params (not the query body).

All values with no default are reset to their zero value.

func (*UploadSourceMapParams) SetHTTPClient

func (o *UploadSourceMapParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the upload source map params

func (*UploadSourceMapParams) SetTimeout

func (o *UploadSourceMapParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the upload source map params

func (*UploadSourceMapParams) WithContext

WithContext adds the context to the upload source map params

func (*UploadSourceMapParams) WithDefaults

func (o *UploadSourceMapParams) WithDefaults() *UploadSourceMapParams

WithDefaults hydrates default values in the upload source map params (not the query body).

All values with no default are reset to their zero value.

func (*UploadSourceMapParams) WithHTTPClient

func (o *UploadSourceMapParams) WithHTTPClient(client *http.Client) *UploadSourceMapParams

WithHTTPClient adds the HTTPClient to the upload source map params

func (*UploadSourceMapParams) WithTimeout

func (o *UploadSourceMapParams) WithTimeout(timeout time.Duration) *UploadSourceMapParams

WithTimeout adds the timeout to the upload source map params

func (*UploadSourceMapParams) WriteToRequest

func (o *UploadSourceMapParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error

WriteToRequest writes these params to a swagger request

type UploadSourceMapReader

type UploadSourceMapReader struct {
	// contains filtered or unexported fields
}

UploadSourceMapReader is a Reader for the UploadSourceMap structure.

func (*UploadSourceMapReader) ReadResponse

func (o *UploadSourceMapReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (any, error)

ReadResponse reads a server response into the received o.

type UploadSourceMapRequestEntityTooLarge

type UploadSourceMapRequestEntityTooLarge struct {
	Payload *models.ErrorResponse
}

UploadSourceMapRequestEntityTooLarge describes a response with status code 413, with default header values.

UploadSourceMapRequestEntityTooLarge upload source map request entity too large

func NewUploadSourceMapRequestEntityTooLarge

func NewUploadSourceMapRequestEntityTooLarge() *UploadSourceMapRequestEntityTooLarge

NewUploadSourceMapRequestEntityTooLarge creates a UploadSourceMapRequestEntityTooLarge with default headers values

func (*UploadSourceMapRequestEntityTooLarge) Code

Code gets the status code for the upload source map request entity too large response

func (*UploadSourceMapRequestEntityTooLarge) Error

func (*UploadSourceMapRequestEntityTooLarge) GetPayload

func (*UploadSourceMapRequestEntityTooLarge) IsClientError

func (o *UploadSourceMapRequestEntityTooLarge) IsClientError() bool

IsClientError returns true when this upload source map request entity too large response has a 4xx status code

func (*UploadSourceMapRequestEntityTooLarge) IsCode

IsCode returns true when this upload source map request entity too large response a status code equal to that given

func (*UploadSourceMapRequestEntityTooLarge) IsRedirect

IsRedirect returns true when this upload source map request entity too large response has a 3xx status code

func (*UploadSourceMapRequestEntityTooLarge) IsServerError

func (o *UploadSourceMapRequestEntityTooLarge) IsServerError() bool

IsServerError returns true when this upload source map request entity too large response has a 5xx status code

func (*UploadSourceMapRequestEntityTooLarge) IsSuccess

IsSuccess returns true when this upload source map request entity too large response has a 2xx status code

func (*UploadSourceMapRequestEntityTooLarge) String

type UploadSourceMapServiceUnavailable

type UploadSourceMapServiceUnavailable struct {
	Payload *models.ErrorResponse
}

UploadSourceMapServiceUnavailable describes a response with status code 503, with default header values.

UploadSourceMapServiceUnavailable upload source map service unavailable

func NewUploadSourceMapServiceUnavailable

func NewUploadSourceMapServiceUnavailable() *UploadSourceMapServiceUnavailable

NewUploadSourceMapServiceUnavailable creates a UploadSourceMapServiceUnavailable with default headers values

func (*UploadSourceMapServiceUnavailable) Code

Code gets the status code for the upload source map service unavailable response

func (*UploadSourceMapServiceUnavailable) Error

func (*UploadSourceMapServiceUnavailable) GetPayload

func (*UploadSourceMapServiceUnavailable) IsClientError

func (o *UploadSourceMapServiceUnavailable) IsClientError() bool

IsClientError returns true when this upload source map service unavailable response has a 4xx status code

func (*UploadSourceMapServiceUnavailable) IsCode

func (o *UploadSourceMapServiceUnavailable) IsCode(code int) bool

IsCode returns true when this upload source map service unavailable response a status code equal to that given

func (*UploadSourceMapServiceUnavailable) IsRedirect

func (o *UploadSourceMapServiceUnavailable) IsRedirect() bool

IsRedirect returns true when this upload source map service unavailable response has a 3xx status code

func (*UploadSourceMapServiceUnavailable) IsServerError

func (o *UploadSourceMapServiceUnavailable) IsServerError() bool

IsServerError returns true when this upload source map service unavailable response has a 5xx status code

func (*UploadSourceMapServiceUnavailable) IsSuccess

func (o *UploadSourceMapServiceUnavailable) IsSuccess() bool

IsSuccess returns true when this upload source map service unavailable response has a 2xx status code

func (*UploadSourceMapServiceUnavailable) String

Jump to