Documentation
¶
Index ¶
- func WithContentTypeApplicationJSON(r *runtime.ClientOperation)
- func WithContentTypeTextPlain(r *runtime.ClientOperation)
- type Client
- func (a *Client) CreateWorkflow(params *CreateWorkflowParams, authInfo runtime.ClientAuthInfoWriter, ...) (*CreateWorkflowAccepted, error)
- func (a *Client) DeleteWorkflow(params *DeleteWorkflowParams, authInfo runtime.ClientAuthInfoWriter, ...) (*DeleteWorkflowOK, error)
- func (a *Client) ListWorkflows(params *ListWorkflowsParams, authInfo runtime.ClientAuthInfoWriter, ...) (*ListWorkflowsOK, error)
- func (a *Client) SetTransport(transport runtime.ClientTransport)
- type ClientOption
- type ClientService
- type CreateWorkflowAccepted
- func (o *CreateWorkflowAccepted) Code() int
- func (o *CreateWorkflowAccepted) Error() string
- func (o *CreateWorkflowAccepted) GetPayload() *models.CreateWorkflowResponse
- func (o *CreateWorkflowAccepted) IsClientError() bool
- func (o *CreateWorkflowAccepted) IsCode(code int) bool
- func (o *CreateWorkflowAccepted) IsRedirect() bool
- func (o *CreateWorkflowAccepted) IsServerError() bool
- func (o *CreateWorkflowAccepted) IsSuccess() bool
- func (o *CreateWorkflowAccepted) String() string
- type CreateWorkflowBadRequest
- func (o *CreateWorkflowBadRequest) Code() int
- func (o *CreateWorkflowBadRequest) Error() string
- func (o *CreateWorkflowBadRequest) GetPayload() *CreateWorkflowBadRequestBody
- func (o *CreateWorkflowBadRequest) IsClientError() bool
- func (o *CreateWorkflowBadRequest) IsCode(code int) bool
- func (o *CreateWorkflowBadRequest) IsRedirect() bool
- func (o *CreateWorkflowBadRequest) IsServerError() bool
- func (o *CreateWorkflowBadRequest) IsSuccess() bool
- func (o *CreateWorkflowBadRequest) String() string
- type CreateWorkflowBadRequestBody
- func (o *CreateWorkflowBadRequestBody) ContextValidate(ctx context.Context, formats strfmt.Registry) error
- func (o *CreateWorkflowBadRequestBody) MarshalBinary() ([]byte, error)
- func (o *CreateWorkflowBadRequestBody) UnmarshalBinary(b []byte) error
- func (o *CreateWorkflowBadRequestBody) Validate(formats strfmt.Registry) error
- type CreateWorkflowInternalServerError
- func (o *CreateWorkflowInternalServerError) Code() int
- func (o *CreateWorkflowInternalServerError) Error() string
- func (o *CreateWorkflowInternalServerError) GetPayload() *CreateWorkflowInternalServerErrorBody
- func (o *CreateWorkflowInternalServerError) IsClientError() bool
- func (o *CreateWorkflowInternalServerError) IsCode(code int) bool
- func (o *CreateWorkflowInternalServerError) IsRedirect() bool
- func (o *CreateWorkflowInternalServerError) IsServerError() bool
- func (o *CreateWorkflowInternalServerError) IsSuccess() bool
- func (o *CreateWorkflowInternalServerError) String() string
- type CreateWorkflowInternalServerErrorBody
- func (o *CreateWorkflowInternalServerErrorBody) ContextValidate(ctx context.Context, formats strfmt.Registry) error
- func (o *CreateWorkflowInternalServerErrorBody) MarshalBinary() ([]byte, error)
- func (o *CreateWorkflowInternalServerErrorBody) UnmarshalBinary(b []byte) error
- func (o *CreateWorkflowInternalServerErrorBody) Validate(formats strfmt.Registry) error
- type CreateWorkflowParams
- func NewCreateWorkflowParams() *CreateWorkflowParams
- func NewCreateWorkflowParamsWithContext(ctx context.Context) *CreateWorkflowParams
- func NewCreateWorkflowParamsWithHTTPClient(client *http.Client) *CreateWorkflowParams
- func NewCreateWorkflowParamsWithTimeout(timeout time.Duration) *CreateWorkflowParams
- func (o *CreateWorkflowParams) SetBody(body string)
- func (o *CreateWorkflowParams) SetContext(ctx context.Context)
- func (o *CreateWorkflowParams) SetDefaults()
- func (o *CreateWorkflowParams) SetHTTPClient(client *http.Client)
- func (o *CreateWorkflowParams) SetTimeout(timeout time.Duration)
- func (o *CreateWorkflowParams) WithBody(body string) *CreateWorkflowParams
- func (o *CreateWorkflowParams) WithContext(ctx context.Context) *CreateWorkflowParams
- func (o *CreateWorkflowParams) WithDefaults() *CreateWorkflowParams
- func (o *CreateWorkflowParams) WithHTTPClient(client *http.Client) *CreateWorkflowParams
- func (o *CreateWorkflowParams) WithTimeout(timeout time.Duration) *CreateWorkflowParams
- func (o *CreateWorkflowParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
- type CreateWorkflowReader
- type CreateWorkflowUnauthorized
- func (o *CreateWorkflowUnauthorized) Code() int
- func (o *CreateWorkflowUnauthorized) Error() string
- func (o *CreateWorkflowUnauthorized) GetPayload() *CreateWorkflowUnauthorizedBody
- func (o *CreateWorkflowUnauthorized) IsClientError() bool
- func (o *CreateWorkflowUnauthorized) IsCode(code int) bool
- func (o *CreateWorkflowUnauthorized) IsRedirect() bool
- func (o *CreateWorkflowUnauthorized) IsServerError() bool
- func (o *CreateWorkflowUnauthorized) IsSuccess() bool
- func (o *CreateWorkflowUnauthorized) String() string
- type CreateWorkflowUnauthorizedBody
- func (o *CreateWorkflowUnauthorizedBody) ContextValidate(ctx context.Context, formats strfmt.Registry) error
- func (o *CreateWorkflowUnauthorizedBody) MarshalBinary() ([]byte, error)
- func (o *CreateWorkflowUnauthorizedBody) UnmarshalBinary(b []byte) error
- func (o *CreateWorkflowUnauthorizedBody) Validate(formats strfmt.Registry) error
- type DeleteWorkflowBadRequest
- func (o *DeleteWorkflowBadRequest) Code() int
- func (o *DeleteWorkflowBadRequest) Error() string
- func (o *DeleteWorkflowBadRequest) GetPayload() *DeleteWorkflowBadRequestBody
- func (o *DeleteWorkflowBadRequest) IsClientError() bool
- func (o *DeleteWorkflowBadRequest) IsCode(code int) bool
- func (o *DeleteWorkflowBadRequest) IsRedirect() bool
- func (o *DeleteWorkflowBadRequest) IsServerError() bool
- func (o *DeleteWorkflowBadRequest) IsSuccess() bool
- func (o *DeleteWorkflowBadRequest) String() string
- type DeleteWorkflowBadRequestBody
- func (o *DeleteWorkflowBadRequestBody) ContextValidate(ctx context.Context, formats strfmt.Registry) error
- func (o *DeleteWorkflowBadRequestBody) MarshalBinary() ([]byte, error)
- func (o *DeleteWorkflowBadRequestBody) UnmarshalBinary(b []byte) error
- func (o *DeleteWorkflowBadRequestBody) Validate(formats strfmt.Registry) error
- type DeleteWorkflowInternalServerError
- func (o *DeleteWorkflowInternalServerError) Code() int
- func (o *DeleteWorkflowInternalServerError) Error() string
- func (o *DeleteWorkflowInternalServerError) GetPayload() *DeleteWorkflowInternalServerErrorBody
- func (o *DeleteWorkflowInternalServerError) IsClientError() bool
- func (o *DeleteWorkflowInternalServerError) IsCode(code int) bool
- func (o *DeleteWorkflowInternalServerError) IsRedirect() bool
- func (o *DeleteWorkflowInternalServerError) IsServerError() bool
- func (o *DeleteWorkflowInternalServerError) IsSuccess() bool
- func (o *DeleteWorkflowInternalServerError) String() string
- type DeleteWorkflowInternalServerErrorBody
- func (o *DeleteWorkflowInternalServerErrorBody) ContextValidate(ctx context.Context, formats strfmt.Registry) error
- func (o *DeleteWorkflowInternalServerErrorBody) MarshalBinary() ([]byte, error)
- func (o *DeleteWorkflowInternalServerErrorBody) UnmarshalBinary(b []byte) error
- func (o *DeleteWorkflowInternalServerErrorBody) Validate(formats strfmt.Registry) error
- type DeleteWorkflowOK
- func (o *DeleteWorkflowOK) Code() int
- func (o *DeleteWorkflowOK) Error() string
- func (o *DeleteWorkflowOK) GetPayload() any
- func (o *DeleteWorkflowOK) IsClientError() bool
- func (o *DeleteWorkflowOK) IsCode(code int) bool
- func (o *DeleteWorkflowOK) IsRedirect() bool
- func (o *DeleteWorkflowOK) IsServerError() bool
- func (o *DeleteWorkflowOK) IsSuccess() bool
- func (o *DeleteWorkflowOK) String() string
- type DeleteWorkflowParams
- func NewDeleteWorkflowParams() *DeleteWorkflowParams
- func NewDeleteWorkflowParamsWithContext(ctx context.Context) *DeleteWorkflowParams
- func NewDeleteWorkflowParamsWithHTTPClient(client *http.Client) *DeleteWorkflowParams
- func NewDeleteWorkflowParamsWithTimeout(timeout time.Duration) *DeleteWorkflowParams
- func (o *DeleteWorkflowParams) SetContext(ctx context.Context)
- func (o *DeleteWorkflowParams) SetDefaults()
- func (o *DeleteWorkflowParams) SetHTTPClient(client *http.Client)
- func (o *DeleteWorkflowParams) SetID(id string)
- func (o *DeleteWorkflowParams) SetTimeout(timeout time.Duration)
- func (o *DeleteWorkflowParams) WithContext(ctx context.Context) *DeleteWorkflowParams
- func (o *DeleteWorkflowParams) WithDefaults() *DeleteWorkflowParams
- func (o *DeleteWorkflowParams) WithHTTPClient(client *http.Client) *DeleteWorkflowParams
- func (o *DeleteWorkflowParams) WithID(id string) *DeleteWorkflowParams
- func (o *DeleteWorkflowParams) WithTimeout(timeout time.Duration) *DeleteWorkflowParams
- func (o *DeleteWorkflowParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
- type DeleteWorkflowReader
- type DeleteWorkflowUnauthorized
- func (o *DeleteWorkflowUnauthorized) Code() int
- func (o *DeleteWorkflowUnauthorized) Error() string
- func (o *DeleteWorkflowUnauthorized) GetPayload() *DeleteWorkflowUnauthorizedBody
- func (o *DeleteWorkflowUnauthorized) IsClientError() bool
- func (o *DeleteWorkflowUnauthorized) IsCode(code int) bool
- func (o *DeleteWorkflowUnauthorized) IsRedirect() bool
- func (o *DeleteWorkflowUnauthorized) IsServerError() bool
- func (o *DeleteWorkflowUnauthorized) IsSuccess() bool
- func (o *DeleteWorkflowUnauthorized) String() string
- type DeleteWorkflowUnauthorizedBody
- func (o *DeleteWorkflowUnauthorizedBody) ContextValidate(ctx context.Context, formats strfmt.Registry) error
- func (o *DeleteWorkflowUnauthorizedBody) MarshalBinary() ([]byte, error)
- func (o *DeleteWorkflowUnauthorizedBody) UnmarshalBinary(b []byte) error
- func (o *DeleteWorkflowUnauthorizedBody) Validate(formats strfmt.Registry) error
- type ListWorkflowsInternalServerError
- func (o *ListWorkflowsInternalServerError) Code() int
- func (o *ListWorkflowsInternalServerError) Error() string
- func (o *ListWorkflowsInternalServerError) GetPayload() *ListWorkflowsInternalServerErrorBody
- func (o *ListWorkflowsInternalServerError) IsClientError() bool
- func (o *ListWorkflowsInternalServerError) IsCode(code int) bool
- func (o *ListWorkflowsInternalServerError) IsRedirect() bool
- func (o *ListWorkflowsInternalServerError) IsServerError() bool
- func (o *ListWorkflowsInternalServerError) IsSuccess() bool
- func (o *ListWorkflowsInternalServerError) String() string
- type ListWorkflowsInternalServerErrorBody
- func (o *ListWorkflowsInternalServerErrorBody) ContextValidate(ctx context.Context, formats strfmt.Registry) error
- func (o *ListWorkflowsInternalServerErrorBody) MarshalBinary() ([]byte, error)
- func (o *ListWorkflowsInternalServerErrorBody) UnmarshalBinary(b []byte) error
- func (o *ListWorkflowsInternalServerErrorBody) Validate(formats strfmt.Registry) error
- type ListWorkflowsOK
- func (o *ListWorkflowsOK) Code() int
- func (o *ListWorkflowsOK) Error() string
- func (o *ListWorkflowsOK) GetPayload() *models.WorkflowsResponse
- func (o *ListWorkflowsOK) IsClientError() bool
- func (o *ListWorkflowsOK) IsCode(code int) bool
- func (o *ListWorkflowsOK) IsRedirect() bool
- func (o *ListWorkflowsOK) IsServerError() bool
- func (o *ListWorkflowsOK) IsSuccess() bool
- func (o *ListWorkflowsOK) String() string
- type ListWorkflowsParams
- func (o *ListWorkflowsParams) SetContext(ctx context.Context)
- func (o *ListWorkflowsParams) SetDefaults()
- func (o *ListWorkflowsParams) SetHTTPClient(client *http.Client)
- func (o *ListWorkflowsParams) SetTimeout(timeout time.Duration)
- func (o *ListWorkflowsParams) WithContext(ctx context.Context) *ListWorkflowsParams
- func (o *ListWorkflowsParams) WithDefaults() *ListWorkflowsParams
- func (o *ListWorkflowsParams) WithHTTPClient(client *http.Client) *ListWorkflowsParams
- func (o *ListWorkflowsParams) WithTimeout(timeout time.Duration) *ListWorkflowsParams
- func (o *ListWorkflowsParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
- type ListWorkflowsReader
- type ListWorkflowsUnauthorized
- func (o *ListWorkflowsUnauthorized) Code() int
- func (o *ListWorkflowsUnauthorized) Error() string
- func (o *ListWorkflowsUnauthorized) GetPayload() *ListWorkflowsUnauthorizedBody
- func (o *ListWorkflowsUnauthorized) IsClientError() bool
- func (o *ListWorkflowsUnauthorized) IsCode(code int) bool
- func (o *ListWorkflowsUnauthorized) IsRedirect() bool
- func (o *ListWorkflowsUnauthorized) IsServerError() bool
- func (o *ListWorkflowsUnauthorized) IsSuccess() bool
- func (o *ListWorkflowsUnauthorized) String() string
- type ListWorkflowsUnauthorizedBody
- func (o *ListWorkflowsUnauthorizedBody) ContextValidate(ctx context.Context, formats strfmt.Registry) error
- func (o *ListWorkflowsUnauthorizedBody) MarshalBinary() ([]byte, error)
- func (o *ListWorkflowsUnauthorizedBody) UnmarshalBinary(b []byte) error
- func (o *ListWorkflowsUnauthorizedBody) Validate(formats strfmt.Registry) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func WithContentTypeApplicationJSON ¶
func WithContentTypeApplicationJSON(r *runtime.ClientOperation)
WithContentTypeApplicationJSON sets the Content-Type header to "application/json".
func WithContentTypeTextPlain ¶
func WithContentTypeTextPlain(r *runtime.ClientOperation)
WithContentTypeTextPlain sets the Content-Type header to "text/plain".
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client for workflows API
func (*Client) CreateWorkflow ¶
func (a *Client) CreateWorkflow(params *CreateWorkflowParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*CreateWorkflowAccepted, error)
CreateWorkflow creates workflow
Creates a new workflow from the provided definition.
func (*Client) DeleteWorkflow ¶
func (a *Client) DeleteWorkflow(params *DeleteWorkflowParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*DeleteWorkflowOK, error)
DeleteWorkflow deletes workflow
Deletes a workflow by its unique identifier.
func (*Client) ListWorkflows ¶
func (a *Client) ListWorkflows(params *ListWorkflowsParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*ListWorkflowsOK, error)
ListWorkflows lists workflows
Retrieves all workflows for the authenticated user.
func (*Client) SetTransport ¶
func (a *Client) SetTransport(transport runtime.ClientTransport)
SetTransport changes the transport on the client
type ClientOption ¶
type ClientOption func(*runtime.ClientOperation)
ClientOption may be used to customize the behavior of Client methods.
func WithContentType ¶
func WithContentType(mime string) ClientOption
WithContentType allows the client to force the Content-Type header to negotiate a specific Consumer from the server.
You may use this option to set arbitrary extensions to your MIME media type.
type ClientService ¶
type ClientService interface {
CreateWorkflow(params *CreateWorkflowParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*CreateWorkflowAccepted, error)
DeleteWorkflow(params *DeleteWorkflowParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*DeleteWorkflowOK, error)
ListWorkflows(params *ListWorkflowsParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*ListWorkflowsOK, error)
SetTransport(transport runtime.ClientTransport)
}
ClientService is the interface for Client methods
func New ¶
func New(transport runtime.ClientTransport, formats strfmt.Registry) ClientService
New creates a new workflows API client.
func NewClientWithBasicAuth ¶
func NewClientWithBasicAuth(host, basePath, scheme, user, password string) ClientService
New creates a new workflows API client with basic auth credentials. It takes the following parameters: - host: http host (github.com). - basePath: any base path for the API client ("/v1", "/v3"). - scheme: http scheme ("http", "https"). - user: user for basic authentication header. - password: password for basic authentication header.
func NewClientWithBearerToken ¶
func NewClientWithBearerToken(host, basePath, scheme, bearerToken string) ClientService
New creates a new workflows API client with a bearer token for authentication. It takes the following parameters: - host: http host (github.com). - basePath: any base path for the API client ("/v1", "/v3"). - scheme: http scheme ("http", "https"). - bearerToken: bearer token for Bearer authentication header.
type CreateWorkflowAccepted ¶
type CreateWorkflowAccepted struct {
Payload *models.CreateWorkflowResponse
}
CreateWorkflowAccepted describes a response with status code 202, with default header values.
CreateWorkflowAccepted create workflow accepted
func NewCreateWorkflowAccepted ¶
func NewCreateWorkflowAccepted() *CreateWorkflowAccepted
NewCreateWorkflowAccepted creates a CreateWorkflowAccepted with default headers values
func (*CreateWorkflowAccepted) Code ¶
func (o *CreateWorkflowAccepted) Code() int
Code gets the status code for the create workflow accepted response
func (*CreateWorkflowAccepted) Error ¶
func (o *CreateWorkflowAccepted) Error() string
func (*CreateWorkflowAccepted) GetPayload ¶
func (o *CreateWorkflowAccepted) GetPayload() *models.CreateWorkflowResponse
func (*CreateWorkflowAccepted) IsClientError ¶
func (o *CreateWorkflowAccepted) IsClientError() bool
IsClientError returns true when this create workflow accepted response has a 4xx status code
func (*CreateWorkflowAccepted) IsCode ¶
func (o *CreateWorkflowAccepted) IsCode(code int) bool
IsCode returns true when this create workflow accepted response a status code equal to that given
func (*CreateWorkflowAccepted) IsRedirect ¶
func (o *CreateWorkflowAccepted) IsRedirect() bool
IsRedirect returns true when this create workflow accepted response has a 3xx status code
func (*CreateWorkflowAccepted) IsServerError ¶
func (o *CreateWorkflowAccepted) IsServerError() bool
IsServerError returns true when this create workflow accepted response has a 5xx status code
func (*CreateWorkflowAccepted) IsSuccess ¶
func (o *CreateWorkflowAccepted) IsSuccess() bool
IsSuccess returns true when this create workflow accepted response has a 2xx status code
func (*CreateWorkflowAccepted) String ¶
func (o *CreateWorkflowAccepted) String() string
type CreateWorkflowBadRequest ¶
type CreateWorkflowBadRequest struct {
Payload *CreateWorkflowBadRequestBody
}
CreateWorkflowBadRequest describes a response with status code 400, with default header values.
ErrorResponse defines a common error response structure.
func NewCreateWorkflowBadRequest ¶
func NewCreateWorkflowBadRequest() *CreateWorkflowBadRequest
NewCreateWorkflowBadRequest creates a CreateWorkflowBadRequest with default headers values
func (*CreateWorkflowBadRequest) Code ¶
func (o *CreateWorkflowBadRequest) Code() int
Code gets the status code for the create workflow bad request response
func (*CreateWorkflowBadRequest) Error ¶
func (o *CreateWorkflowBadRequest) Error() string
func (*CreateWorkflowBadRequest) GetPayload ¶
func (o *CreateWorkflowBadRequest) GetPayload() *CreateWorkflowBadRequestBody
func (*CreateWorkflowBadRequest) IsClientError ¶
func (o *CreateWorkflowBadRequest) IsClientError() bool
IsClientError returns true when this create workflow bad request response has a 4xx status code
func (*CreateWorkflowBadRequest) IsCode ¶
func (o *CreateWorkflowBadRequest) IsCode(code int) bool
IsCode returns true when this create workflow bad request response a status code equal to that given
func (*CreateWorkflowBadRequest) IsRedirect ¶
func (o *CreateWorkflowBadRequest) IsRedirect() bool
IsRedirect returns true when this create workflow bad request response has a 3xx status code
func (*CreateWorkflowBadRequest) IsServerError ¶
func (o *CreateWorkflowBadRequest) IsServerError() bool
IsServerError returns true when this create workflow bad request response has a 5xx status code
func (*CreateWorkflowBadRequest) IsSuccess ¶
func (o *CreateWorkflowBadRequest) IsSuccess() bool
IsSuccess returns true when this create workflow bad request response has a 2xx status code
func (*CreateWorkflowBadRequest) String ¶
func (o *CreateWorkflowBadRequest) String() string
type CreateWorkflowBadRequestBody ¶
type CreateWorkflowBadRequestBody struct {
// message
Message string `json:"message,omitempty"`
}
CreateWorkflowBadRequestBody create workflow bad request body swagger:model CreateWorkflowBadRequestBody
func (*CreateWorkflowBadRequestBody) ContextValidate ¶
func (o *CreateWorkflowBadRequestBody) ContextValidate(ctx context.Context, formats strfmt.Registry) error
ContextValidate validates this create workflow bad request body based on context it is used
func (*CreateWorkflowBadRequestBody) MarshalBinary ¶
func (o *CreateWorkflowBadRequestBody) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*CreateWorkflowBadRequestBody) UnmarshalBinary ¶
func (o *CreateWorkflowBadRequestBody) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type CreateWorkflowInternalServerError ¶
type CreateWorkflowInternalServerError struct {
Payload *CreateWorkflowInternalServerErrorBody
}
CreateWorkflowInternalServerError describes a response with status code 500, with default header values.
ErrorResponse defines a common error response structure.
func NewCreateWorkflowInternalServerError ¶
func NewCreateWorkflowInternalServerError() *CreateWorkflowInternalServerError
NewCreateWorkflowInternalServerError creates a CreateWorkflowInternalServerError with default headers values
func (*CreateWorkflowInternalServerError) Code ¶
func (o *CreateWorkflowInternalServerError) Code() int
Code gets the status code for the create workflow internal server error response
func (*CreateWorkflowInternalServerError) Error ¶
func (o *CreateWorkflowInternalServerError) Error() string
func (*CreateWorkflowInternalServerError) GetPayload ¶
func (o *CreateWorkflowInternalServerError) GetPayload() *CreateWorkflowInternalServerErrorBody
func (*CreateWorkflowInternalServerError) IsClientError ¶
func (o *CreateWorkflowInternalServerError) IsClientError() bool
IsClientError returns true when this create workflow internal server error response has a 4xx status code
func (*CreateWorkflowInternalServerError) IsCode ¶
func (o *CreateWorkflowInternalServerError) IsCode(code int) bool
IsCode returns true when this create workflow internal server error response a status code equal to that given
func (*CreateWorkflowInternalServerError) IsRedirect ¶
func (o *CreateWorkflowInternalServerError) IsRedirect() bool
IsRedirect returns true when this create workflow internal server error response has a 3xx status code
func (*CreateWorkflowInternalServerError) IsServerError ¶
func (o *CreateWorkflowInternalServerError) IsServerError() bool
IsServerError returns true when this create workflow internal server error response has a 5xx status code
func (*CreateWorkflowInternalServerError) IsSuccess ¶
func (o *CreateWorkflowInternalServerError) IsSuccess() bool
IsSuccess returns true when this create workflow internal server error response has a 2xx status code
func (*CreateWorkflowInternalServerError) String ¶
func (o *CreateWorkflowInternalServerError) String() string
type CreateWorkflowInternalServerErrorBody ¶
type CreateWorkflowInternalServerErrorBody struct {
// message
Message string `json:"message,omitempty"`
}
CreateWorkflowInternalServerErrorBody create workflow internal server error body swagger:model CreateWorkflowInternalServerErrorBody
func (*CreateWorkflowInternalServerErrorBody) ContextValidate ¶
func (o *CreateWorkflowInternalServerErrorBody) ContextValidate(ctx context.Context, formats strfmt.Registry) error
ContextValidate validates this create workflow internal server error body based on context it is used
func (*CreateWorkflowInternalServerErrorBody) MarshalBinary ¶
func (o *CreateWorkflowInternalServerErrorBody) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*CreateWorkflowInternalServerErrorBody) UnmarshalBinary ¶
func (o *CreateWorkflowInternalServerErrorBody) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type CreateWorkflowParams ¶
type CreateWorkflowParams struct {
/* Body.
Workflow definition in raw format
*/
Body string
Context context.Context
HTTPClient *http.Client
// contains filtered or unexported fields
}
CreateWorkflowParams contains all the parameters to send to the API endpoint
for the create workflow operation. Typically these are written to a http.Request.
func NewCreateWorkflowParams ¶
func NewCreateWorkflowParams() *CreateWorkflowParams
NewCreateWorkflowParams creates a new CreateWorkflowParams object, with the default timeout for this client.
Default values are not hydrated, since defaults are normally applied by the API server side.
To enforce default values in parameter, use SetDefaults or WithDefaults.
func NewCreateWorkflowParamsWithContext ¶
func NewCreateWorkflowParamsWithContext(ctx context.Context) *CreateWorkflowParams
NewCreateWorkflowParamsWithContext creates a new CreateWorkflowParams object with the ability to set a context for a request.
func NewCreateWorkflowParamsWithHTTPClient ¶
func NewCreateWorkflowParamsWithHTTPClient(client *http.Client) *CreateWorkflowParams
NewCreateWorkflowParamsWithHTTPClient creates a new CreateWorkflowParams object with the ability to set a custom HTTPClient for a request.
func NewCreateWorkflowParamsWithTimeout ¶
func NewCreateWorkflowParamsWithTimeout(timeout time.Duration) *CreateWorkflowParams
NewCreateWorkflowParamsWithTimeout creates a new CreateWorkflowParams object with the ability to set a timeout on a request.
func (*CreateWorkflowParams) SetBody ¶
func (o *CreateWorkflowParams) SetBody(body string)
SetBody adds the body to the create workflow params
func (*CreateWorkflowParams) SetContext ¶
func (o *CreateWorkflowParams) SetContext(ctx context.Context)
SetContext adds the context to the create workflow params
func (*CreateWorkflowParams) SetDefaults ¶
func (o *CreateWorkflowParams) SetDefaults()
SetDefaults hydrates default values in the create workflow params (not the query body).
All values with no default are reset to their zero value.
func (*CreateWorkflowParams) SetHTTPClient ¶
func (o *CreateWorkflowParams) SetHTTPClient(client *http.Client)
SetHTTPClient adds the HTTPClient to the create workflow params
func (*CreateWorkflowParams) SetTimeout ¶
func (o *CreateWorkflowParams) SetTimeout(timeout time.Duration)
SetTimeout adds the timeout to the create workflow params
func (*CreateWorkflowParams) WithBody ¶
func (o *CreateWorkflowParams) WithBody(body string) *CreateWorkflowParams
WithBody adds the body to the create workflow params
func (*CreateWorkflowParams) WithContext ¶
func (o *CreateWorkflowParams) WithContext(ctx context.Context) *CreateWorkflowParams
WithContext adds the context to the create workflow params
func (*CreateWorkflowParams) WithDefaults ¶
func (o *CreateWorkflowParams) WithDefaults() *CreateWorkflowParams
WithDefaults hydrates default values in the create workflow params (not the query body).
All values with no default are reset to their zero value.
func (*CreateWorkflowParams) WithHTTPClient ¶
func (o *CreateWorkflowParams) WithHTTPClient(client *http.Client) *CreateWorkflowParams
WithHTTPClient adds the HTTPClient to the create workflow params
func (*CreateWorkflowParams) WithTimeout ¶
func (o *CreateWorkflowParams) WithTimeout(timeout time.Duration) *CreateWorkflowParams
WithTimeout adds the timeout to the create workflow params
func (*CreateWorkflowParams) WriteToRequest ¶
func (o *CreateWorkflowParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
WriteToRequest writes these params to a swagger request
type CreateWorkflowReader ¶
type CreateWorkflowReader struct {
// contains filtered or unexported fields
}
CreateWorkflowReader is a Reader for the CreateWorkflow structure.
func (*CreateWorkflowReader) ReadResponse ¶
func (o *CreateWorkflowReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (any, error)
ReadResponse reads a server response into the received o.
type CreateWorkflowUnauthorized ¶
type CreateWorkflowUnauthorized struct {
}
CreateWorkflowUnauthorized describes a response with status code 401, with default header values.
ErrorResponse defines a common error response structure.
func NewCreateWorkflowUnauthorized ¶
func NewCreateWorkflowUnauthorized() *CreateWorkflowUnauthorized
NewCreateWorkflowUnauthorized creates a CreateWorkflowUnauthorized with default headers values
func (*CreateWorkflowUnauthorized) Code ¶
func (o *CreateWorkflowUnauthorized) Code() int
Code gets the status code for the create workflow unauthorized response
func (*CreateWorkflowUnauthorized) Error ¶
func (o *CreateWorkflowUnauthorized) Error() string
func (*CreateWorkflowUnauthorized) GetPayload ¶
func (o *CreateWorkflowUnauthorized) GetPayload() *CreateWorkflowUnauthorizedBody
func (*CreateWorkflowUnauthorized) IsClientError ¶
func (o *CreateWorkflowUnauthorized) IsClientError() bool
IsClientError returns true when this create workflow unauthorized response has a 4xx status code
func (*CreateWorkflowUnauthorized) IsCode ¶
func (o *CreateWorkflowUnauthorized) IsCode(code int) bool
IsCode returns true when this create workflow unauthorized response a status code equal to that given
func (*CreateWorkflowUnauthorized) IsRedirect ¶
func (o *CreateWorkflowUnauthorized) IsRedirect() bool
IsRedirect returns true when this create workflow unauthorized response has a 3xx status code
func (*CreateWorkflowUnauthorized) IsServerError ¶
func (o *CreateWorkflowUnauthorized) IsServerError() bool
IsServerError returns true when this create workflow unauthorized response has a 5xx status code
func (*CreateWorkflowUnauthorized) IsSuccess ¶
func (o *CreateWorkflowUnauthorized) IsSuccess() bool
IsSuccess returns true when this create workflow unauthorized response has a 2xx status code
func (*CreateWorkflowUnauthorized) String ¶
func (o *CreateWorkflowUnauthorized) String() string
type CreateWorkflowUnauthorizedBody ¶
type CreateWorkflowUnauthorizedBody struct {
Message string `json:"message,omitempty"`
}
CreateWorkflowUnauthorizedBody create workflow unauthorized body swagger:model CreateWorkflowUnauthorizedBody
func (*CreateWorkflowUnauthorizedBody) ContextValidate ¶
func (o *CreateWorkflowUnauthorizedBody) ContextValidate(ctx context.Context, formats strfmt.Registry) error
ContextValidate validates this create workflow unauthorized body based on context it is used
func (*CreateWorkflowUnauthorizedBody) MarshalBinary ¶
func (o *CreateWorkflowUnauthorizedBody) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*CreateWorkflowUnauthorizedBody) UnmarshalBinary ¶
func (o *CreateWorkflowUnauthorizedBody) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type DeleteWorkflowBadRequest ¶
type DeleteWorkflowBadRequest struct {
Payload *DeleteWorkflowBadRequestBody
}
DeleteWorkflowBadRequest describes a response with status code 400, with default header values.
ErrorResponse defines a common error response structure.
func NewDeleteWorkflowBadRequest ¶
func NewDeleteWorkflowBadRequest() *DeleteWorkflowBadRequest
NewDeleteWorkflowBadRequest creates a DeleteWorkflowBadRequest with default headers values
func (*DeleteWorkflowBadRequest) Code ¶
func (o *DeleteWorkflowBadRequest) Code() int
Code gets the status code for the delete workflow bad request response
func (*DeleteWorkflowBadRequest) Error ¶
func (o *DeleteWorkflowBadRequest) Error() string
func (*DeleteWorkflowBadRequest) GetPayload ¶
func (o *DeleteWorkflowBadRequest) GetPayload() *DeleteWorkflowBadRequestBody
func (*DeleteWorkflowBadRequest) IsClientError ¶
func (o *DeleteWorkflowBadRequest) IsClientError() bool
IsClientError returns true when this delete workflow bad request response has a 4xx status code
func (*DeleteWorkflowBadRequest) IsCode ¶
func (o *DeleteWorkflowBadRequest) IsCode(code int) bool
IsCode returns true when this delete workflow bad request response a status code equal to that given
func (*DeleteWorkflowBadRequest) IsRedirect ¶
func (o *DeleteWorkflowBadRequest) IsRedirect() bool
IsRedirect returns true when this delete workflow bad request response has a 3xx status code
func (*DeleteWorkflowBadRequest) IsServerError ¶
func (o *DeleteWorkflowBadRequest) IsServerError() bool
IsServerError returns true when this delete workflow bad request response has a 5xx status code
func (*DeleteWorkflowBadRequest) IsSuccess ¶
func (o *DeleteWorkflowBadRequest) IsSuccess() bool
IsSuccess returns true when this delete workflow bad request response has a 2xx status code
func (*DeleteWorkflowBadRequest) String ¶
func (o *DeleteWorkflowBadRequest) String() string
type DeleteWorkflowBadRequestBody ¶
type DeleteWorkflowBadRequestBody struct {
// message
Message string `json:"message,omitempty"`
}
DeleteWorkflowBadRequestBody delete workflow bad request body swagger:model DeleteWorkflowBadRequestBody
func (*DeleteWorkflowBadRequestBody) ContextValidate ¶
func (o *DeleteWorkflowBadRequestBody) ContextValidate(ctx context.Context, formats strfmt.Registry) error
ContextValidate validates this delete workflow bad request body based on context it is used
func (*DeleteWorkflowBadRequestBody) MarshalBinary ¶
func (o *DeleteWorkflowBadRequestBody) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*DeleteWorkflowBadRequestBody) UnmarshalBinary ¶
func (o *DeleteWorkflowBadRequestBody) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type DeleteWorkflowInternalServerError ¶
type DeleteWorkflowInternalServerError struct {
Payload *DeleteWorkflowInternalServerErrorBody
}
DeleteWorkflowInternalServerError describes a response with status code 500, with default header values.
ErrorResponse defines a common error response structure.
func NewDeleteWorkflowInternalServerError ¶
func NewDeleteWorkflowInternalServerError() *DeleteWorkflowInternalServerError
NewDeleteWorkflowInternalServerError creates a DeleteWorkflowInternalServerError with default headers values
func (*DeleteWorkflowInternalServerError) Code ¶
func (o *DeleteWorkflowInternalServerError) Code() int
Code gets the status code for the delete workflow internal server error response
func (*DeleteWorkflowInternalServerError) Error ¶
func (o *DeleteWorkflowInternalServerError) Error() string
func (*DeleteWorkflowInternalServerError) GetPayload ¶
func (o *DeleteWorkflowInternalServerError) GetPayload() *DeleteWorkflowInternalServerErrorBody
func (*DeleteWorkflowInternalServerError) IsClientError ¶
func (o *DeleteWorkflowInternalServerError) IsClientError() bool
IsClientError returns true when this delete workflow internal server error response has a 4xx status code
func (*DeleteWorkflowInternalServerError) IsCode ¶
func (o *DeleteWorkflowInternalServerError) IsCode(code int) bool
IsCode returns true when this delete workflow internal server error response a status code equal to that given
func (*DeleteWorkflowInternalServerError) IsRedirect ¶
func (o *DeleteWorkflowInternalServerError) IsRedirect() bool
IsRedirect returns true when this delete workflow internal server error response has a 3xx status code
func (*DeleteWorkflowInternalServerError) IsServerError ¶
func (o *DeleteWorkflowInternalServerError) IsServerError() bool
IsServerError returns true when this delete workflow internal server error response has a 5xx status code
func (*DeleteWorkflowInternalServerError) IsSuccess ¶
func (o *DeleteWorkflowInternalServerError) IsSuccess() bool
IsSuccess returns true when this delete workflow internal server error response has a 2xx status code
func (*DeleteWorkflowInternalServerError) String ¶
func (o *DeleteWorkflowInternalServerError) String() string
type DeleteWorkflowInternalServerErrorBody ¶
type DeleteWorkflowInternalServerErrorBody struct {
// message
Message string `json:"message,omitempty"`
}
DeleteWorkflowInternalServerErrorBody delete workflow internal server error body swagger:model DeleteWorkflowInternalServerErrorBody
func (*DeleteWorkflowInternalServerErrorBody) ContextValidate ¶
func (o *DeleteWorkflowInternalServerErrorBody) ContextValidate(ctx context.Context, formats strfmt.Registry) error
ContextValidate validates this delete workflow internal server error body based on context it is used
func (*DeleteWorkflowInternalServerErrorBody) MarshalBinary ¶
func (o *DeleteWorkflowInternalServerErrorBody) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*DeleteWorkflowInternalServerErrorBody) UnmarshalBinary ¶
func (o *DeleteWorkflowInternalServerErrorBody) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type DeleteWorkflowOK ¶
type DeleteWorkflowOK struct {
Payload any
}
DeleteWorkflowOK describes a response with status code 200, with default header values.
DeleteWorkflowOK delete workflow o k
func NewDeleteWorkflowOK ¶
func NewDeleteWorkflowOK() *DeleteWorkflowOK
NewDeleteWorkflowOK creates a DeleteWorkflowOK with default headers values
func (*DeleteWorkflowOK) Code ¶
func (o *DeleteWorkflowOK) Code() int
Code gets the status code for the delete workflow o k response
func (*DeleteWorkflowOK) Error ¶
func (o *DeleteWorkflowOK) Error() string
func (*DeleteWorkflowOK) GetPayload ¶
func (o *DeleteWorkflowOK) GetPayload() any
func (*DeleteWorkflowOK) IsClientError ¶
func (o *DeleteWorkflowOK) IsClientError() bool
IsClientError returns true when this delete workflow o k response has a 4xx status code
func (*DeleteWorkflowOK) IsCode ¶
func (o *DeleteWorkflowOK) IsCode(code int) bool
IsCode returns true when this delete workflow o k response a status code equal to that given
func (*DeleteWorkflowOK) IsRedirect ¶
func (o *DeleteWorkflowOK) IsRedirect() bool
IsRedirect returns true when this delete workflow o k response has a 3xx status code
func (*DeleteWorkflowOK) IsServerError ¶
func (o *DeleteWorkflowOK) IsServerError() bool
IsServerError returns true when this delete workflow o k response has a 5xx status code
func (*DeleteWorkflowOK) IsSuccess ¶
func (o *DeleteWorkflowOK) IsSuccess() bool
IsSuccess returns true when this delete workflow o k response has a 2xx status code
func (*DeleteWorkflowOK) String ¶
func (o *DeleteWorkflowOK) String() string
type DeleteWorkflowParams ¶
type DeleteWorkflowParams struct {
/* ID.
Unique identifier of the workflow to delete
*/
ID string
Context context.Context
HTTPClient *http.Client
// contains filtered or unexported fields
}
DeleteWorkflowParams contains all the parameters to send to the API endpoint
for the delete workflow operation. Typically these are written to a http.Request.
func NewDeleteWorkflowParams ¶
func NewDeleteWorkflowParams() *DeleteWorkflowParams
NewDeleteWorkflowParams creates a new DeleteWorkflowParams object, with the default timeout for this client.
Default values are not hydrated, since defaults are normally applied by the API server side.
To enforce default values in parameter, use SetDefaults or WithDefaults.
func NewDeleteWorkflowParamsWithContext ¶
func NewDeleteWorkflowParamsWithContext(ctx context.Context) *DeleteWorkflowParams
NewDeleteWorkflowParamsWithContext creates a new DeleteWorkflowParams object with the ability to set a context for a request.
func NewDeleteWorkflowParamsWithHTTPClient ¶
func NewDeleteWorkflowParamsWithHTTPClient(client *http.Client) *DeleteWorkflowParams
NewDeleteWorkflowParamsWithHTTPClient creates a new DeleteWorkflowParams object with the ability to set a custom HTTPClient for a request.
func NewDeleteWorkflowParamsWithTimeout ¶
func NewDeleteWorkflowParamsWithTimeout(timeout time.Duration) *DeleteWorkflowParams
NewDeleteWorkflowParamsWithTimeout creates a new DeleteWorkflowParams object with the ability to set a timeout on a request.
func (*DeleteWorkflowParams) SetContext ¶
func (o *DeleteWorkflowParams) SetContext(ctx context.Context)
SetContext adds the context to the delete workflow params
func (*DeleteWorkflowParams) SetDefaults ¶
func (o *DeleteWorkflowParams) SetDefaults()
SetDefaults hydrates default values in the delete workflow params (not the query body).
All values with no default are reset to their zero value.
func (*DeleteWorkflowParams) SetHTTPClient ¶
func (o *DeleteWorkflowParams) SetHTTPClient(client *http.Client)
SetHTTPClient adds the HTTPClient to the delete workflow params
func (*DeleteWorkflowParams) SetID ¶
func (o *DeleteWorkflowParams) SetID(id string)
SetID adds the id to the delete workflow params
func (*DeleteWorkflowParams) SetTimeout ¶
func (o *DeleteWorkflowParams) SetTimeout(timeout time.Duration)
SetTimeout adds the timeout to the delete workflow params
func (*DeleteWorkflowParams) WithContext ¶
func (o *DeleteWorkflowParams) WithContext(ctx context.Context) *DeleteWorkflowParams
WithContext adds the context to the delete workflow params
func (*DeleteWorkflowParams) WithDefaults ¶
func (o *DeleteWorkflowParams) WithDefaults() *DeleteWorkflowParams
WithDefaults hydrates default values in the delete workflow params (not the query body).
All values with no default are reset to their zero value.
func (*DeleteWorkflowParams) WithHTTPClient ¶
func (o *DeleteWorkflowParams) WithHTTPClient(client *http.Client) *DeleteWorkflowParams
WithHTTPClient adds the HTTPClient to the delete workflow params
func (*DeleteWorkflowParams) WithID ¶
func (o *DeleteWorkflowParams) WithID(id string) *DeleteWorkflowParams
WithID adds the id to the delete workflow params
func (*DeleteWorkflowParams) WithTimeout ¶
func (o *DeleteWorkflowParams) WithTimeout(timeout time.Duration) *DeleteWorkflowParams
WithTimeout adds the timeout to the delete workflow params
func (*DeleteWorkflowParams) WriteToRequest ¶
func (o *DeleteWorkflowParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
WriteToRequest writes these params to a swagger request
type DeleteWorkflowReader ¶
type DeleteWorkflowReader struct {
// contains filtered or unexported fields
}
DeleteWorkflowReader is a Reader for the DeleteWorkflow structure.
func (*DeleteWorkflowReader) ReadResponse ¶
func (o *DeleteWorkflowReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (any, error)
ReadResponse reads a server response into the received o.
type DeleteWorkflowUnauthorized ¶
type DeleteWorkflowUnauthorized struct {
}
DeleteWorkflowUnauthorized describes a response with status code 401, with default header values.
ErrorResponse defines a common error response structure.
func NewDeleteWorkflowUnauthorized ¶
func NewDeleteWorkflowUnauthorized() *DeleteWorkflowUnauthorized
NewDeleteWorkflowUnauthorized creates a DeleteWorkflowUnauthorized with default headers values
func (*DeleteWorkflowUnauthorized) Code ¶
func (o *DeleteWorkflowUnauthorized) Code() int
Code gets the status code for the delete workflow unauthorized response
func (*DeleteWorkflowUnauthorized) Error ¶
func (o *DeleteWorkflowUnauthorized) Error() string
func (*DeleteWorkflowUnauthorized) GetPayload ¶
func (o *DeleteWorkflowUnauthorized) GetPayload() *DeleteWorkflowUnauthorizedBody
func (*DeleteWorkflowUnauthorized) IsClientError ¶
func (o *DeleteWorkflowUnauthorized) IsClientError() bool
IsClientError returns true when this delete workflow unauthorized response has a 4xx status code
func (*DeleteWorkflowUnauthorized) IsCode ¶
func (o *DeleteWorkflowUnauthorized) IsCode(code int) bool
IsCode returns true when this delete workflow unauthorized response a status code equal to that given
func (*DeleteWorkflowUnauthorized) IsRedirect ¶
func (o *DeleteWorkflowUnauthorized) IsRedirect() bool
IsRedirect returns true when this delete workflow unauthorized response has a 3xx status code
func (*DeleteWorkflowUnauthorized) IsServerError ¶
func (o *DeleteWorkflowUnauthorized) IsServerError() bool
IsServerError returns true when this delete workflow unauthorized response has a 5xx status code
func (*DeleteWorkflowUnauthorized) IsSuccess ¶
func (o *DeleteWorkflowUnauthorized) IsSuccess() bool
IsSuccess returns true when this delete workflow unauthorized response has a 2xx status code
func (*DeleteWorkflowUnauthorized) String ¶
func (o *DeleteWorkflowUnauthorized) String() string
type DeleteWorkflowUnauthorizedBody ¶
type DeleteWorkflowUnauthorizedBody struct {
Message string `json:"message,omitempty"`
}
DeleteWorkflowUnauthorizedBody delete workflow unauthorized body swagger:model DeleteWorkflowUnauthorizedBody
func (*DeleteWorkflowUnauthorizedBody) ContextValidate ¶
func (o *DeleteWorkflowUnauthorizedBody) ContextValidate(ctx context.Context, formats strfmt.Registry) error
ContextValidate validates this delete workflow unauthorized body based on context it is used
func (*DeleteWorkflowUnauthorizedBody) MarshalBinary ¶
func (o *DeleteWorkflowUnauthorizedBody) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*DeleteWorkflowUnauthorizedBody) UnmarshalBinary ¶
func (o *DeleteWorkflowUnauthorizedBody) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type ListWorkflowsInternalServerError ¶
type ListWorkflowsInternalServerError struct {
Payload *ListWorkflowsInternalServerErrorBody
}
ListWorkflowsInternalServerError describes a response with status code 500, with default header values.
ErrorResponse defines a common error response structure.
func NewListWorkflowsInternalServerError ¶
func NewListWorkflowsInternalServerError() *ListWorkflowsInternalServerError
NewListWorkflowsInternalServerError creates a ListWorkflowsInternalServerError with default headers values
func (*ListWorkflowsInternalServerError) Code ¶
func (o *ListWorkflowsInternalServerError) Code() int
Code gets the status code for the list workflows internal server error response
func (*ListWorkflowsInternalServerError) Error ¶
func (o *ListWorkflowsInternalServerError) Error() string
func (*ListWorkflowsInternalServerError) GetPayload ¶
func (o *ListWorkflowsInternalServerError) GetPayload() *ListWorkflowsInternalServerErrorBody
func (*ListWorkflowsInternalServerError) IsClientError ¶
func (o *ListWorkflowsInternalServerError) IsClientError() bool
IsClientError returns true when this list workflows internal server error response has a 4xx status code
func (*ListWorkflowsInternalServerError) IsCode ¶
func (o *ListWorkflowsInternalServerError) IsCode(code int) bool
IsCode returns true when this list workflows internal server error response a status code equal to that given
func (*ListWorkflowsInternalServerError) IsRedirect ¶
func (o *ListWorkflowsInternalServerError) IsRedirect() bool
IsRedirect returns true when this list workflows internal server error response has a 3xx status code
func (*ListWorkflowsInternalServerError) IsServerError ¶
func (o *ListWorkflowsInternalServerError) IsServerError() bool
IsServerError returns true when this list workflows internal server error response has a 5xx status code
func (*ListWorkflowsInternalServerError) IsSuccess ¶
func (o *ListWorkflowsInternalServerError) IsSuccess() bool
IsSuccess returns true when this list workflows internal server error response has a 2xx status code
func (*ListWorkflowsInternalServerError) String ¶
func (o *ListWorkflowsInternalServerError) String() string
type ListWorkflowsInternalServerErrorBody ¶
type ListWorkflowsInternalServerErrorBody struct {
// message
Message string `json:"message,omitempty"`
}
ListWorkflowsInternalServerErrorBody list workflows internal server error body swagger:model ListWorkflowsInternalServerErrorBody
func (*ListWorkflowsInternalServerErrorBody) ContextValidate ¶
func (o *ListWorkflowsInternalServerErrorBody) ContextValidate(ctx context.Context, formats strfmt.Registry) error
ContextValidate validates this list workflows internal server error body based on context it is used
func (*ListWorkflowsInternalServerErrorBody) MarshalBinary ¶
func (o *ListWorkflowsInternalServerErrorBody) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*ListWorkflowsInternalServerErrorBody) UnmarshalBinary ¶
func (o *ListWorkflowsInternalServerErrorBody) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type ListWorkflowsOK ¶
type ListWorkflowsOK struct {
Payload *models.WorkflowsResponse
}
ListWorkflowsOK describes a response with status code 200, with default header values.
ListWorkflowsOK list workflows o k
func NewListWorkflowsOK ¶
func NewListWorkflowsOK() *ListWorkflowsOK
NewListWorkflowsOK creates a ListWorkflowsOK with default headers values
func (*ListWorkflowsOK) Code ¶
func (o *ListWorkflowsOK) Code() int
Code gets the status code for the list workflows o k response
func (*ListWorkflowsOK) Error ¶
func (o *ListWorkflowsOK) Error() string
func (*ListWorkflowsOK) GetPayload ¶
func (o *ListWorkflowsOK) GetPayload() *models.WorkflowsResponse
func (*ListWorkflowsOK) IsClientError ¶
func (o *ListWorkflowsOK) IsClientError() bool
IsClientError returns true when this list workflows o k response has a 4xx status code
func (*ListWorkflowsOK) IsCode ¶
func (o *ListWorkflowsOK) IsCode(code int) bool
IsCode returns true when this list workflows o k response a status code equal to that given
func (*ListWorkflowsOK) IsRedirect ¶
func (o *ListWorkflowsOK) IsRedirect() bool
IsRedirect returns true when this list workflows o k response has a 3xx status code
func (*ListWorkflowsOK) IsServerError ¶
func (o *ListWorkflowsOK) IsServerError() bool
IsServerError returns true when this list workflows o k response has a 5xx status code
func (*ListWorkflowsOK) IsSuccess ¶
func (o *ListWorkflowsOK) IsSuccess() bool
IsSuccess returns true when this list workflows o k response has a 2xx status code
func (*ListWorkflowsOK) String ¶
func (o *ListWorkflowsOK) String() string
type ListWorkflowsParams ¶
type ListWorkflowsParams struct {
Context context.Context
HTTPClient *http.Client
// contains filtered or unexported fields
}
ListWorkflowsParams contains all the parameters to send to the API endpoint
for the list workflows operation. Typically these are written to a http.Request.
func NewListWorkflowsParams ¶
func NewListWorkflowsParams() *ListWorkflowsParams
NewListWorkflowsParams creates a new ListWorkflowsParams object, with the default timeout for this client.
Default values are not hydrated, since defaults are normally applied by the API server side.
To enforce default values in parameter, use SetDefaults or WithDefaults.
func NewListWorkflowsParamsWithContext ¶
func NewListWorkflowsParamsWithContext(ctx context.Context) *ListWorkflowsParams
NewListWorkflowsParamsWithContext creates a new ListWorkflowsParams object with the ability to set a context for a request.
func NewListWorkflowsParamsWithHTTPClient ¶
func NewListWorkflowsParamsWithHTTPClient(client *http.Client) *ListWorkflowsParams
NewListWorkflowsParamsWithHTTPClient creates a new ListWorkflowsParams object with the ability to set a custom HTTPClient for a request.
func NewListWorkflowsParamsWithTimeout ¶
func NewListWorkflowsParamsWithTimeout(timeout time.Duration) *ListWorkflowsParams
NewListWorkflowsParamsWithTimeout creates a new ListWorkflowsParams object with the ability to set a timeout on a request.
func (*ListWorkflowsParams) SetContext ¶
func (o *ListWorkflowsParams) SetContext(ctx context.Context)
SetContext adds the context to the list workflows params
func (*ListWorkflowsParams) SetDefaults ¶
func (o *ListWorkflowsParams) SetDefaults()
SetDefaults hydrates default values in the list workflows params (not the query body).
All values with no default are reset to their zero value.
func (*ListWorkflowsParams) SetHTTPClient ¶
func (o *ListWorkflowsParams) SetHTTPClient(client *http.Client)
SetHTTPClient adds the HTTPClient to the list workflows params
func (*ListWorkflowsParams) SetTimeout ¶
func (o *ListWorkflowsParams) SetTimeout(timeout time.Duration)
SetTimeout adds the timeout to the list workflows params
func (*ListWorkflowsParams) WithContext ¶
func (o *ListWorkflowsParams) WithContext(ctx context.Context) *ListWorkflowsParams
WithContext adds the context to the list workflows params
func (*ListWorkflowsParams) WithDefaults ¶
func (o *ListWorkflowsParams) WithDefaults() *ListWorkflowsParams
WithDefaults hydrates default values in the list workflows params (not the query body).
All values with no default are reset to their zero value.
func (*ListWorkflowsParams) WithHTTPClient ¶
func (o *ListWorkflowsParams) WithHTTPClient(client *http.Client) *ListWorkflowsParams
WithHTTPClient adds the HTTPClient to the list workflows params
func (*ListWorkflowsParams) WithTimeout ¶
func (o *ListWorkflowsParams) WithTimeout(timeout time.Duration) *ListWorkflowsParams
WithTimeout adds the timeout to the list workflows params
func (*ListWorkflowsParams) WriteToRequest ¶
func (o *ListWorkflowsParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
WriteToRequest writes these params to a swagger request
type ListWorkflowsReader ¶
type ListWorkflowsReader struct {
// contains filtered or unexported fields
}
ListWorkflowsReader is a Reader for the ListWorkflows structure.
func (*ListWorkflowsReader) ReadResponse ¶
func (o *ListWorkflowsReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (any, error)
ReadResponse reads a server response into the received o.
type ListWorkflowsUnauthorized ¶
type ListWorkflowsUnauthorized struct {
}
ListWorkflowsUnauthorized describes a response with status code 401, with default header values.
ErrorResponse defines a common error response structure.
func NewListWorkflowsUnauthorized ¶
func NewListWorkflowsUnauthorized() *ListWorkflowsUnauthorized
NewListWorkflowsUnauthorized creates a ListWorkflowsUnauthorized with default headers values
func (*ListWorkflowsUnauthorized) Code ¶
func (o *ListWorkflowsUnauthorized) Code() int
Code gets the status code for the list workflows unauthorized response
func (*ListWorkflowsUnauthorized) Error ¶
func (o *ListWorkflowsUnauthorized) Error() string
func (*ListWorkflowsUnauthorized) GetPayload ¶
func (o *ListWorkflowsUnauthorized) GetPayload() *ListWorkflowsUnauthorizedBody
func (*ListWorkflowsUnauthorized) IsClientError ¶
func (o *ListWorkflowsUnauthorized) IsClientError() bool
IsClientError returns true when this list workflows unauthorized response has a 4xx status code
func (*ListWorkflowsUnauthorized) IsCode ¶
func (o *ListWorkflowsUnauthorized) IsCode(code int) bool
IsCode returns true when this list workflows unauthorized response a status code equal to that given
func (*ListWorkflowsUnauthorized) IsRedirect ¶
func (o *ListWorkflowsUnauthorized) IsRedirect() bool
IsRedirect returns true when this list workflows unauthorized response has a 3xx status code
func (*ListWorkflowsUnauthorized) IsServerError ¶
func (o *ListWorkflowsUnauthorized) IsServerError() bool
IsServerError returns true when this list workflows unauthorized response has a 5xx status code
func (*ListWorkflowsUnauthorized) IsSuccess ¶
func (o *ListWorkflowsUnauthorized) IsSuccess() bool
IsSuccess returns true when this list workflows unauthorized response has a 2xx status code
func (*ListWorkflowsUnauthorized) String ¶
func (o *ListWorkflowsUnauthorized) String() string
type ListWorkflowsUnauthorizedBody ¶
type ListWorkflowsUnauthorizedBody struct {
Message string `json:"message,omitempty"`
}
ListWorkflowsUnauthorizedBody list workflows unauthorized body swagger:model ListWorkflowsUnauthorizedBody
func (*ListWorkflowsUnauthorizedBody) ContextValidate ¶
func (o *ListWorkflowsUnauthorizedBody) ContextValidate(ctx context.Context, formats strfmt.Registry) error
ContextValidate validates this list workflows unauthorized body based on context it is used
func (*ListWorkflowsUnauthorizedBody) MarshalBinary ¶
func (o *ListWorkflowsUnauthorizedBody) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*ListWorkflowsUnauthorizedBody) UnmarshalBinary ¶
func (o *ListWorkflowsUnauthorizedBody) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation